package MT::Plugin::SKR::LogSummary;

use strict;
use MT 4;
use MT::Blog;
use MT::Template;
use MT::Log;
use MT::Mail;
use Data::Dumper;#DEBUG

use vars qw( $MYNAME $VERSION );
$MYNAME = 'LogSummary';
$VERSION = '0.02';

use base qw( MT::Plugin );
my $plugin = __PACKAGE__->new({
    name => $MYNAME,
    id => lc $MYNAME,
    key => lc $MYNAME,
    version => $VERSION,
    author_name => 'SKYARC System Co.,Ltd.',
    author_link => 'http://www.skyarc.co.jp/',
    doc_link => 'http://www.skyarc.co.jp/engineerblog/entry/logsummary.html',
    description => <<PERLHEREDOC,
<__trans phrase="Send a summary mail of log.">
PERLHEREDOC
    blog_config_template => 'config.tmpl',
    settings => new MT::PluginSettings([
        [ 'to', { Default => undef, scope => 'blog' } ],
    ]),
});
MT->add_plugin ($plugin);

sub instance { $plugin; }

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
        tasks => {
            $MYNAME => {
                label => 'Send a summary mail of log',
                frequency => 60 * 60 * 24,
                code => \&_task_log_summary,
            },
        },
    });
}



###
sub _task_log_summary {
    my ($cb) = @_;

    my $cfg = MT->instance->config;
    my $from_addr = $cfg->EmailAddressMain;

    my @t = gmtime (time - 60 * 60 * 24);
    my $ts = sprintf '%04d%02d%02d%02d%02d%02d', $t[5]+1900, $t[4]+1, @t[3,2,1,0];

    my $iter = MT::Blog->load_iter ();
    while (my $blog = $iter->()) {
        # Get configuration
        my $to = &instance->get_config_value ('to', 'blog:'. $blog->id)
            or next; # not yet configured
        # Mail Template
        my $tmpl = MT::Template->load ({ blog_id => $blog->id, name => $MYNAME, })
            or next; # no template exist
        my $ctx = $tmpl->context;
        $ctx->stash ('blog', $blog);

        # Retrieve logs and set to variable
        my $count = 0;
        map {
            my $args = {};
            $args->{name} = sprintf 'log[%d]', $count++;
            my $created_on = $_->created_on;
            $created_on =~ s/(\d{4})(\d{2})(\d{2})(\d{2})(\d{2})(\d{2})/$1-$2-$3 $4:$5:$6/;
            $args->{value} = sprintf "%s\t%s\t%s\n",
                $created_on,
                $_->ip ? $_->ip : '-',
                $_->message;
            $ctx->tag ('SetVar', $args);
        } MT::Log->load ({
            blog_id => $blog->id, class => '*', created_on => [ $ts, 29991231235959 ]
        }, {
            range => { created_on => 1 }, sort => 'created_on', direction => 'ascend',
        });

        # Build template
        my ($mail_title, $mail_body) = $tmpl->output =~ /^(.+)[\r\n]+([\s\S]+)/;

        # Send Mail
        foreach (split /[\r\n]+/, $to) {
            my %head = (
                Subject => $mail_title,
                $from_addr ? (From => $from_addr) : (),
                To => $_,
            );
            MT::Mail->send (\%head, $mail_body);
        }
    }
}

1;
